@@ -1,5 +1,5 @@
 
-# $Id: Ebay.pm,v 2.260 2013/06/24 03:12:21 martin Exp $
+# $Id: Ebay.pm,v 2.261 2013-08-20 22:16:03 Martin Exp $
 
 =head1 NAME
 
@@ -139,7 +139,7 @@ use WWW::SearchResult 2.072;
 use WWW::Search::Result;
 
 our
-$VERSION = do { my @r = (q$Revision: 2.260 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 2.261 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 our $MAINTAINER = 'Martin Thurn <mthurn@cpan.org>';
 my $cgi = new CGI;
 
@@ -469,6 +469,11 @@ sub _parse_bids
       $iBids = 0;
       } # if
     } # if
+  if ($iBids =~ m/NO/i)
+    {
+    $iBids = 0;
+    } # if
+  $iBids ||= 0;
   $hit->bid_count($iBids);
   return 1;
   } # _parse_bids
